==> Pyrogram-2.0.63-py3-none-any.whl: pyrogram/raw/functions/channels/__init__.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .read_history import ReadHistory
from .delete_messages import DeleteMessages
from .report_spam import ReportSpam
from .get_messages import GetMessages
from .get_participants import GetParticipants
from .get_participant import GetParticipant
from .get_channels import GetChannels
from .get_full_channel import GetFullChannel
from .create_channel import CreateChannel
from .edit_admin import EditAdmin
from .edit_title import EditTitle
from .edit_photo import EditPhoto
from .check_username import CheckUsername
from .update_username import UpdateUsername
from .join_channel import JoinChannel
from .leave_channel import LeaveChannel
from .invite_to_channel import InviteToChannel
from .delete_channel import DeleteChannel
from .export_message_link import ExportMessageLink
from .toggle_signatures import ToggleSignatures
from .get_admined_public_channels import GetAdminedPublicChannels
from .edit_banned import EditBanned
from .get_admin_log import GetAdminLog
from .set_stickers import SetStickers
from .read_message_contents import ReadMessageContents
from .delete_history import DeleteHistory
from .toggle_pre_history_hidden import TogglePreHistoryHidden
from .get_left_channels import GetLeftChannels
from .get_groups_for_discussion import GetGroupsForDiscussion
from .set_discussion_group import SetDiscussionGroup
from .edit_creator import EditCreator
from .edit_location import EditLocation
from .toggle_slow_mode import ToggleSlowMode
from .get_inactive_channels import GetInactiveChannels
from .convert_to_gigagroup import ConvertToGigagroup
from .view_sponsored_message import ViewSponsoredMessage
from .get_sponsored_messages import GetSponsoredMessages
from .get_send_as import GetSendAs
from .delete_participant_history import DeleteParticipantHistory
from .toggle_join_to_send import ToggleJoinToSend
from .toggle_join_request import ToggleJoinRequest
from .reorder_usernames import ReorderUsernames
from .toggle_username import ToggleUsername
from .deactivate_all_usernames import DeactivateAllUsernames
from .toggle_forum import ToggleForum
from .create_forum_topic import CreateForumTopic
from .get_forum_topics import GetForumTopics
from .get_forum_topics_by_id import GetForumTopicsByID
from .edit_forum_topic import EditForumTopic
from .update_pinned_forum_topic import UpdatePinnedForumTopic
from .delete_topic_history import DeleteTopicHistory
from .reorder_pinned_forum_topics import ReorderPinnedForumTopics

==> Pyrogram-2.0.70-py3-none-any.whl: pyrogram/raw/functions/channels/__init__.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .read_history import ReadHistory
from .delete_messages import DeleteMessages
from .report_spam import ReportSpam
from .get_messages import GetMessages
from .get_participants import GetParticipants
from .get_participant import GetParticipant
from .get_channels import GetChannels
from .get_full_channel import GetFullChannel
from .create_channel import CreateChannel
from .edit_admin import EditAdmin
from .edit_title import EditTitle
from .edit_photo import EditPhoto
from .check_username import CheckUsername
from .update_username import UpdateUsername
from .join_channel import JoinChannel
from .leave_channel import LeaveChannel
from .invite_to_channel import InviteToChannel
from .delete_channel import DeleteChannel
from .export_message_link import ExportMessageLink
from .toggle_signatures import ToggleSignatures
from .get_admined_public_channels import GetAdminedPublicChannels
from .edit_banned import EditBanned
from .get_admin_log import GetAdminLog
from .set_stickers import SetStickers
from .read_message_contents import ReadMessageContents
from .delete_history import DeleteHistory
from .toggle_pre_history_hidden import TogglePreHistoryHidden
from .get_left_channels import GetLeftChannels
from .get_groups_for_discussion import GetGroupsForDiscussion
from .set_discussion_group import SetDiscussionGroup
from .edit_creator import EditCreator
from .edit_location import EditLocation
from .toggle_slow_mode import ToggleSlowMode
from .get_inactive_channels import GetInactiveChannels
from .convert_to_gigagroup import ConvertToGigagroup
from .view_sponsored_message import ViewSponsoredMessage
from .get_sponsored_messages import GetSponsoredMessages
from .get_send_as import GetSendAs
from .delete_participant_history import DeleteParticipantHistory
from .toggle_join_to_send import ToggleJoinToSend
from .toggle_join_request import ToggleJoinRequest
from .reorder_usernames import ReorderUsernames
from .toggle_username import ToggleUsername
from .deactivate_all_usernames import DeactivateAllUsernames
from .toggle_forum import ToggleForum
from .create_forum_topic import CreateForumTopic
from .get_forum_topics import GetForumTopics
from .get_forum_topics_by_id import GetForumTopicsByID
from .edit_forum_topic import EditForumTopic
from .update_pinned_forum_topic import UpdatePinnedForumTopic
from .delete_topic_history import DeleteTopicHistory
from .reorder_pinned_forum_topics import ReorderPinnedForumTopics
from .toggle_anti_spam import ToggleAntiSpam
from .report_anti_spam_false_positive import ReportAntiSpamFalsePositive
